Description Usage Arguments Value
View source: R/modular_functions.R
sampleEnv samples from the rejection envelope formed
by the piecewise upper hull for the given function
1 2 3 4 5 6 7 8 9 10 |
n |
The number of samples |
x_abs |
A |
f |
A function representing the target sampling distribution. |
f_params |
A |
supp |
The support of |
z |
The tangent intersection points at given abscissae. |
hx |
The log of the density |
dhdx |
The derivative of the log of the density |
A numeric vector containing the sampled values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.